yt.analysis_modules.halo_finding.halo_objects.LoadTextHaloes.write_particle_lists_txt — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.LoadTextHaloes.write_particle_lists_txt

`LoadTextHaloes.` `write_particle_lists_txt`(prefix)

  Write out the names of the HDF5 files containing halo particle data to a text file.

  This function wirtes out the names of all the HDF5 files that would contain halo particle data. Only the root processor writes out.

  Parameters: | prefix : String The prefix for the name of the file.

  Examples

      >>> halos.write_particle_lists_txt("halo-parts")